%global srcname amqpclt

Name:		python-amqpclt
Version:	0.6
Release:	1%{?dist}
Summary:	Versatile AMQP client
Group:		Development/Libraries
License:	ASL 2.0
URL:		https://github.com/cern-mig/%{name}
Source0:	https://pypi.python.org/packages/99/80/6ed044c4da3906ee693518fe26715d108d40bfe8f267ec6e813aadf292b5/amqpclt-0.6.tar.gz
BuildRoot:	%{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)

BuildArch:	noarch
BuildRequires:	python-amqplib
BuildRequires:	python-anyjson
BuildRequires:	python-auth-credential
BuildRequires:	python-dirq	
BuildRequires:	python-kombu
BuildRequires:	python-messaging	
BuildRequires:	python-pika
BuildRequires:	python-six
BuildRequires:	python2-devel
BuildRequires:	rabbitmq-server
Requires:	perl-Config-General
Requires:	python-auth-credential
Requires:	python-dirq
Requires:	python-messaging
Requires:	python-pika
Requires:	python-six

%description
amqpclt is a versatile tool to interact with messaging brokers speaking AMQP
and/or message queues (see messaging.queue) on disk.

It receives messages (see messaging.message) from an incoming module,
optionally massaging them (i.e. filtering and/or modifying), and sends
them to an outgoing module. Depending on which modules are used, the tool
can perform different operations.

%prep
%setup -q -n %{srcname}-%{version}

%build 
%{__python} setup.py build

%install
rm -fr %{buildroot}
%{__python} setup.py install --skip-build --root %{buildroot}
install -D -m 644 man/%{srcname}.1 %{buildroot}%{_mandir}/man1/%{srcname}.1

%check
mkdir -p rabbitmq/mnesia rabbitmq/plugins rabbitmq/log
export RABBITMQ_MNESIA_DIR=rabbitmq/mnesia
export RABBITMQ_PID_FILE=rabbitmq/rabbitmq-server.pid
export RABBITMQ_PLUGINS_EXPAND_DIR=rabbitmq/plugins
export RABBITMQ_ENABLED_PLUGINS_FILE=rabbitmq/plugins.enabled
export RABBITMQ_LOG_BASE=rabbitmq/log
export HOSTNAME=localhost
%{_exec_prefix}/lib/rabbitmq/bin/rabbitmq-server -detached
rabbitmqctl=%{_exec_prefix}/lib/rabbitmq/bin/rabbitmqctl
status=0
for i in `seq 1 10`; do
  sleep 3
  if rabbitmqctl status >/dev/null 2>&1; then
    status=0
    break
  else
    status=$i
  fi
done
if [ $status -ne 0 ]; then
  cat $RABBITMQ_LOG_BASE/*.log
  $rabbitmqctl status
fi
$rabbitmqctl environment
export PYTHONPATH=$PYTHONPATH:.
%{__python} setup.py test
%{_exec_prefix}/lib/rabbitmq/bin/rabbitmqctl stop
sleep 3
[ -f %{_bindir}/epmd ] && %{_bindir}/epmd -kill || %{_libdir}/erlang/bin/epmd -kill
# And remove compiled documentation.
rm -f test/*.pyc
rm -rf rabbitmq

%clean
rm -rf %{buildroot}

%files
%defattr(-,root,root)
%doc README.rst CHANGES
%{_mandir}/man?/*
%attr(755, root, root) %{_bindir}/%{srcname}
%{python_sitelib}/%{srcname}/
%{python_sitelib}/%{srcname}-%{version}-py?.?.egg-info

%changelog
* Tue Sep 27 2016 Lionel Cons <lionel.cons@cern.ch> - 0.6-1
- Updated to upstream version.

* Tue Sep 27 2016 Lionel Cons <lionel.cons@cern.ch> - 0.5-8
- Cleaned the obsolete build dependencies.

* Tue Jul 19 2016 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.5-7
- https://fedoraproject.org/wiki/Changes/Automatic_Provides_for_Python_RPM_Packages

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 0.5-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Thu Nov 12 2015 Lionel Cons <lionel.cons@cern.ch> - 0.5-5
- Improved RabbitMQ startup (used in the test phase).

* Thu Jun 18 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.5-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.5-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Sun Aug 04 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.5-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Sun Jun 09 2013 Massimo Paladin <Massimo.Paladin@gmail.com> - 0.5-1
- Updating to latest version, rhbz#970848.

* Thu Feb 14 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.4-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Wed Sep 26 2012 Massimo Paladin <Massimo.Paladin@gmail.com> - 0.4-1
- Updating to latest version.

* Tue Sep 25 2012 Massimo Paladin <Massimo.Paladin@gmail.com> - 0.3-4
- Improved dependencies.

* Tue Sep 25 2012 Massimo Paladin <Massimo.Paladin@gmail.com> - 0.3-3
- BuildRoot now fine.

* Mon Sep 24 2012 Massimo Paladin <Massimo.Paladin@gmail.com> - 0.3-2
- Adjustments plus renaming.

* Tue Sep 04 2012 Massimo Paladin <Massimo.Paladin@gmail.com> - 0.3-1
- Initial packaging.
